==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/DataSourceSpecialRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryResultDescriptionMetadata } from "./SummaryResultDescriptionMetadata";
import { DataSourceSpecialRowDescription } from "./DataSourceSpecialRowDescription";
/**
 * @hidden
 */
var DataSourceSpecialRowDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataSourceSpecialRowDescriptionMetadata, _super);
    function DataSourceSpecialRowDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceSpecialRowDescriptionMetadata.b = function (a) {
        if (DataSourceSpecialRowDescriptionMetadata.a == null) {
            DataSourceSpecialRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceSpecialRowDescriptionMetadata.c(DataSourceSpecialRowDescriptionMetadata.a);
        }
        if (a.g(DataSourceSpecialRowDescriptionMetadata.a)) {
            return;
        }
        a.s(DataSourceSpecialRowDescriptionMetadata.a);
        SummaryResultDescriptionMetadata.d(a);
    };
    DataSourceSpecialRowDescriptionMetadata.c = function (a) {
        a.item("RowType", "ExportedType:string:DataSourceRowType");
        a.item("RowType@names", "Normal;SectionHeader;SectionFooter;ShiftedRow;SummaryRowRoot;SummaryRowSection;Custom");
        a.item("TargetRow", "Unknown");
        a.item("Level", "Number:int");
        a.item("SummaryResults", "Array:SummaryResultDescription:ISummaryResult");
    };
    DataSourceSpecialRowDescriptionMetadata.d = function (a) {
        DataSourceSpecialRowDescriptionMetadata.b(a);
        a.u("DataSourceSpecialRow", function () { return new DataSourceSpecialRowDescription(); });
        a.t("DataSourceSpecialRow", DataSourceSpecialRowDescriptionMetadata.a);
    };
    DataSourceSpecialRowDescriptionMetadata.$t = markType(DataSourceSpecialRowDescriptionMetadata, 'DataSourceSpecialRowDescriptionMetadata');
    DataSourceSpecialRowDescriptionMetadata.a = null;
    return DataSourceSpecialRowDescriptionMetadata;
}(Base));
export { DataSourceSpecialRowDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/DataSourceSpecialRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescriptionMetadata } from "./DataGridSummaryResultDescriptionMetadata";
import { DataSourceSpecialRowDescription } from "./DataSourceSpecialRowDescription";
/**
 * @hidden
 */
var DataSourceSpecialRowDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataSourceSpecialRowDescriptionMetadata, _super);
    function DataSourceSpecialRowDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceSpecialRowDescriptionMetadata.b = function (a) {
        if (DataSourceSpecialRowDescriptionMetadata.a == null) {
            DataSourceSpecialRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceSpecialRowDescriptionMetadata.c(DataSourceSpecialRowDescriptionMetadata.a);
        }
        if (a.j(DataSourceSpecialRowDescriptionMetadata.a)) {
            return;
        }
        a.y(DataSourceSpecialRowDescriptionMetadata.a);
        DataGridSummaryResultDescriptionMetadata.d(a);
    };
    DataSourceSpecialRowDescriptionMetadata.c = function (a) {
        a.item("RowType", "ExportedType:string:DataSourceRowType");
        a.item("RowType@names", "Normal;SectionHeader;SectionFooter;ShiftedRow;SummaryRowRoot;SummaryRowSection;Custom");
        a.item("TargetRow", "Unknown");
        a.item("Level", "Number:int");
        a.item("SummaryResults", "Array:DataGridSummaryResultDescription:ISummaryResult");
    };
    DataSourceSpecialRowDescriptionMetadata.d = function (a) {
        DataSourceSpecialRowDescriptionMetadata.b(a);
        a.aa("DataSourceSpecialRow", function () { return new DataSourceSpecialRowDescription(); });
        a.z("DataSourceSpecialRow", DataSourceSpecialRowDescriptionMetadata.a);
    };
    DataSourceSpecialRowDescriptionMetadata.$t = markType(DataSourceSpecialRowDescriptionMetadata, 'DataSourceSpecialRowDescriptionMetadata');
    DataSourceSpecialRowDescriptionMetadata.a = null;
    return DataSourceSpecialRowDescriptionMetadata;
}(Base));
export { DataSourceSpecialRowDescriptionMetadata };
